#!/usr/bin/env python3

from setuptools import setup

setup(
	name='plover_start_words',
	version='0.0.11',
	description='Plugins for assigning strokes to different output if it starts or not a word',
	long_description='file: README.md',
	author='Noelia Ruiz',
	author_email='nrm1977@gmail.com',
	license='GNU General Public License v3 or later (GPLv3+)',
	url='https://github.com/nvdaes/plover_start_words',
	classifiers=[
		'Development Status :: 1 - Planning',
		'Environment :: Plugins',
		'Intended Audience :: End Users/Desktop',
		'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
		'Operating System :: OS Independent',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.6',
	],
	keywords='plover plover_plugin',
)
